@@ -269,6 +269,8 @@ public abstract class CachingDataStore extends AbstractDataStore implements
             LOG.info("path=[{}],  tmpPath=[{}]", path, tmpDir.getAbsolutePath());
             directory = new File(path);
             mkdirs(directory);
+            mkdirs(new File(homeDir));
+
             if (!mkdirs(tmpDir)) {
                 FileUtils.cleanDirectory(tmpDir);
                 LOG.info("tmp=[{}] cleaned.", tmpDir.getPath());
@@ -993,7 +995,9 @@ public abstract class CachingDataStore extends AbstractDataStore implements
         try {
             DataIdentifier identifier = new DataIdentifier(f.getName());
             usesIdentifier(identifier);
-            backend.write(identifier, f);
+            if (!backend.exists(identifier)) {
+                backend.write(identifier, f);
+            }
             if (updateAsyncUploadCache) {
                 String fileName = getFileName(identifier);
                 asyncWriteCache.remove(fileName);
